@@ -8,6 +8,7 @@ import logging
 import multiprocessing
 import re
 from slapos.runner.process import Popen, isRunning, killRunningProcess
+from slapos.htpasswd import HtpasswdFile
 import shutil
 import os
 import time
@@ -40,7 +41,7 @@ def getSession(config):
   """
   Get the session data of current user.
   Returns:
-    a list of user informations or False if fail to read data.
+    a list of user information or False if fail to read data.
   """
   user_path = os.path.join(config['etc_dir'], '.users')
   user = ""
@@ -64,7 +65,9 @@ def saveSession(config, account):
   Returns:
     True if all goes well or str (error message) if fail
   """
+  # XXX Cedric LN hardcoded path for files
   user = os.path.join(config['etc_dir'], '.users')
+  htpasswdfile = os.path.join(config['etc_dir'], '.htpasswd')
   backup = False
   try:
     if os.path.exists(user):
@@ -78,6 +81,14 @@ def saveSession(config, account):
         account[1] = data.split(';')[1]
     #save new account data
     open(user, 'w').write((';'.join(account)).encode("utf-8"))
+    # Htpasswd file for cloud9
+    # XXX Cedric Le N order of account list values suppose to be fixed
+    # Remove former file to avoid aoutdated accounts
+    if os.path.exists(htpasswdfile):
+      os.remove(htpasswdfile)
+    passwd = HtpasswdFile(htpasswdfile, create=True)
+    passwd.update(account[0], account[1])
+    passwd.save()
     return True
   except Exception as e:
     try:
@@ -332,7 +343,7 @@ def getProfilePath(projectDir, profile):
   return os.path.join(projectFolder, profile)
 
 def getSlapStatus(config):
-  """Return all Slapos Partitions with associate informations"""
+  """Return all Slapos Partitions with associate information"""
   slap = slapos.slap.slap()
   slap.initializeConnection(config['master_url'])
   partition_list = []
@@ -368,7 +379,7 @@ def removeInstanceRoot(config):
     shutil.rmtree(config['instance_root'])
 
 def getSvcStatus(config):
-  """Return all Softwares Instances process Informations"""
+  """Return all Softwares Instances process Information"""
   result = Popen([config['supervisor'], config['configuration_file_path'],
                   'status']).communicate()[0]
   regex = "(^unix:.+\.socket)|(^error:)|(^watchdog).*$"
